'use strict';

var _ = require('lodash');
var debug = require('debug')('generator-ats-node-webapp:app');

module.exports = {
  packageJson: function packageJson() {
    this.appendPackageJson({
      name: _.kebabCase(this.props.name),
      version: this.props.version,
      description: this.props.description,
      homepage: this.props.homepage,
      scripts: {},
      repository: {
        type: 'git',
        url: 'https://github.com/' + this.props.repository
      },
      bugs: {
        url: 'https://github.com/' + this.props.repository + '/issues'
      },
      author: {
        name: this.props.authorName,
        email: this.props.authorEmail,
        url: this.props.authorUrl
      },
      files: ['client'],
      keywords: this.props.keywords
    });
  },

  writeTemplates: function writeTemplates() {
    // Do Nothing
  },

  subgenerators: function subgenerators() {
    var _this = this;

    var composeLocal = function composeLocal(name) {
      debug('composing with generator', name);
      _this.composeWith('ats-node-webapp:' + name, { options: _this.props }, { local: require.resolve('../../' + name) });
    };
    var useOAuthStrategy = function useOAuthStrategy(name) {
      return (_this.props.oauthStrategies || []).indexOf(name) > -1;
    };
    var composeOAuth = function composeOAuth(name) {
      if (useOAuthStrategy(name)) {
        composeLocal('auth-' + name);
      }
    };

    this.props.useOAuthStrategy = useOAuthStrategy;
    debug('generating application with properties', this.props);

    composeLocal('git');
    composeLocal('git-hooks');
    composeLocal('editorconfig');
    composeLocal('eslint');
    composeLocal('readme');
    composeLocal('server-common');
    composeLocal('server-' + this.props.server);

    if (this.props.server !== 'thin') {
      composeLocal('app-symlink');
    }

    composeLocal('docker-compose');
    composeLocal('client-assets');
    composeLocal('client-styles');
    composeLocal('client-build');
    composeLocal('gulp');
    composeLocal('vscode');

    // Add OAuth
    composeOAuth('facebook');
    composeOAuth('github');
    composeOAuth('google');
    composeOAuth('twitter');

    // Add Client
    composeLocal('client-' + this.props.client);

    // Wrap up
    composeLocal('gulp-postinstall');
  }
};